==> codegrade-16.1.89-py3-none-any.whl: codegrade/models/access_token_modal_warning_time_setting.py <==
"""The module that defines the ``AccessTokenModalWarningTimeSetting`` model.

SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
"""

import datetime
import typing as t
from dataclasses import dataclass, field

import cg_request_args as rqa

from ..utils import to_dict


@dataclass
class AccessTokenModalWarningTimeSetting:
    """ """

    name: "t.Literal['ACCESS_TOKEN_MODAL_WARNING_TIME']"
    value: "t.Optional[datetime.timedelta]"

    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)

    data_parser: t.ClassVar = rqa.Lazy(
        lambda: rqa.FixedMapping(
            rqa.RequiredArgument(
                "name",
                rqa.StringEnum("ACCESS_TOKEN_MODAL_WARNING_TIME"),
                doc="",
            ),
            rqa.RequiredArgument(
                "value",
                rqa.Nullable(rqa.RichValue.TimeDelta),
                doc="",
            ),
        ).use_readable_describe(True)
    )

    def to_dict(self) -> t.Dict[str, t.Any]:
        res: t.Dict[str, t.Any] = {
            "name": to_dict(self.name),
            "value": to_dict(self.value),
        }
        return res

    @classmethod
    def from_dict(
        cls: t.Type["AccessTokenModalWarningTimeSetting"],
        d: t.Dict[str, t.Any],
    ) -> "AccessTokenModalWarningTimeSetting":
        parsed = cls.data_parser.try_parse(d)

        res = cls(
            name=parsed.name,
            value=parsed.value,
        )
        res.raw_data = d
        return res

==> codegrade-17.0.1-py3-none-any.whl: codegrade/models/access_token_modal_warning_time_setting.py <==
"""The module that defines the ``AccessTokenModalWarningTimeSetting`` model.

SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
"""

from __future__ import annotations

import datetime
import typing as t
from dataclasses import dataclass, field

import cg_request_args as rqa

from ..utils import to_dict


@dataclass
class AccessTokenModalWarningTimeSetting:
    """ """

    name: t.Literal["ACCESS_TOKEN_MODAL_WARNING_TIME"]
    value: t.Optional[datetime.timedelta]

    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)

    data_parser: t.ClassVar = rqa.Lazy(
        lambda: rqa.FixedMapping(
            rqa.RequiredArgument(
                "name",
                rqa.StringEnum("ACCESS_TOKEN_MODAL_WARNING_TIME"),
                doc="",
            ),
            rqa.RequiredArgument(
                "value",
                rqa.Nullable(rqa.RichValue.TimeDelta),
                doc="",
            ),
        ).use_readable_describe(True)
    )

    def to_dict(self) -> t.Dict[str, t.Any]:
        res: t.Dict[str, t.Any] = {
            "name": to_dict(self.name),
            "value": to_dict(self.value),
        }
        return res

    @classmethod
    def from_dict(
        cls: t.Type[AccessTokenModalWarningTimeSetting], d: t.Dict[str, t.Any]
    ) -> AccessTokenModalWarningTimeSetting:
        parsed = cls.data_parser.try_parse(d)

        res = cls(
            name=parsed.name,
            value=parsed.value,
        )
        res.raw_data = d
        return res
